import requests
import bs4

def query(email, password, query):
    """Runs a single query in a single session to fetch supercontest data
    programatically. It first uses your credentials to retrieve a valid
    CSRF token, then runs the query against the graphql endpoint.

    Args:
        email (str): Your email credential
        password (str): Your password credential (this is passed
            encrypted over https)
        query (str): The graphql query string to run

    Returns:
        (json) The data your query returned
    """
    creds = dict(email=email, password=password)
    root_url = 'https://southbaysupercontest.com'

    with requests.session() as session:
        response = session.get(root_url)
        soup = bs4.BeautifulSoup(response.text, 'html.parser')
        csrf_token = soup.find(id='csrf_token')['value']
        creds['csrf_token'] = csrf_token
        session.post(root_url + '/user/sign-in',
                     data=creds,
                     headers=dict(referer=response.url))
        response = session.get(root_url + '/graphql',
                               json=dict(query=query))
    data = response.json()

    return data



from setuptools import setup
from os import path

this_dir = path.abspath(path.dirname(__file__))
with open(path.join(this_dir, 'README.md'), encoding='utf-8') as f:
    readme = f.read()

setup(
    name='supercontest',
    version='1.0.0',
    description='Client for fetching supercontest data',
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/brianmahlstedt/supercontest',
    author='Brian Mahlstedt',
    author_email='brian.mahlstedt@gmail.com',
    keywords=['supercontest', 'football', 'nfl'],
    license='MIT',
    packages=['supercontest'],
    install_requires=['requests', 'bs4'],
)
